.. _index:

#######
vcspull
#######

.. sidebar:: Contents

    .. toctree::
        :maxdepth: 2

        quickstart
        examples
        cli
        api
        history
        roadmap

.. figure:: _static/vcspull-screenshot.png
    :scale: 100%
    :width: 50%
    :align: center

    Run ``svn update``, ``git pull``, ``hg pull && hg update`` en masse.

.. include:: ../README.rst
    :start-line: 17
